@@ -395,7 +395,7 @@ typedef struct snd_mixer_group {
 #define SND_MIXER_EIO_DIGITAL		(0<<1)
 
 struct snd_mixer_element_io_info {
-	unsigned int attribute;		/* SND_MIXER_EIO_* */
+	unsigned int attrib;		/* SND_MIXER_EIO_* */
 	int voices_size;		/* size in voice descriptors */
 	int voices;			/* count of filled voice descriptors */
 	int voices_over;		/* missing voice descriptors */
@@ -585,7 +585,7 @@ struct snd_mixer_element_accu3 {
 #define SND_MIXER_MUX1_NONE		(1<<0)
 
 struct snd_mixer_element_mux1_info {
-	unsigned int attribute;		/* SND_MIXER_MUX1_ */
+	unsigned int attrib;		/* SND_MIXER_MUX1_ */
 };
 
 struct snd_mixer_element_mux1 {
@@ -604,7 +604,7 @@ struct snd_mixer_element_mux1 {
 #define SND_MIXER_MUX2_NONE		(1<<0)
 
 struct snd_mixer_element_mux2_info {
-	unsigned int attribute;		/* SND_MIXER_MUX1_ */
+	unsigned int attrib;		/* SND_MIXER_MUX1_ */
 };
 
 struct snd_mixer_element_mux2 {
