@@ -69,7 +69,7 @@ snd_kmixer_element_t *snd_mixer_lib_io(snd_kmixer_t *mixer,
 				       char *name,
 				       int index,
 				       int type,
-				       unsigned int attribute,
+				       unsigned int attrib,
 				       int voices_count,
 				       snd_mixer_voice_t *voices)
 {
@@ -103,23 +103,23 @@ snd_kmixer_element_t *snd_mixer_lib_io_mono(snd_kmixer_t *mixer,
 					    char *name,
 					    int index,
 					    int type,
-					    unsigned int attribute)
+					    unsigned int attrib)
 {
 	static snd_mixer_voice_t voice = {SND_MIXER_VOICE_MONO, 0};
-	return snd_mixer_lib_io(mixer, name, index, type, attribute, 1, &voice);
+	return snd_mixer_lib_io(mixer, name, index, type, attrib, 1, &voice);
 }
 
 snd_kmixer_element_t *snd_mixer_lib_io_stereo(snd_kmixer_t *mixer,
 					      char *name,
 					      int index,
 					      int type,
-					      unsigned int attribute)
+					      unsigned int attrib)
 {
 	static snd_mixer_voice_t voices[2] = {
 		{SND_MIXER_VOICE_LEFT, 0},
 		{SND_MIXER_VOICE_RIGHT, 0}
 	};
-	return snd_mixer_lib_io(mixer, name, index, type, attribute, 2, voices);
+	return snd_mixer_lib_io(mixer, name, index, type, attrib, 2, voices);
 }
 
 /*
@@ -1131,7 +1131,7 @@ static int snd_mixer_lib_mux1_info(snd_kmixer_file_t *mfile,
 				   snd_mixer_element_info_t *info,
 				   struct snd_stru_mixer_lib_mux1 *mux1)
 {
-	info->data.mux1.attribute = mux1->attribute;
+	info->data.mux1.attrib = mux1->attrib;
 	return 0;
 }
 
@@ -1200,7 +1200,7 @@ static int snd_mixer_lib_mux1_control(snd_kmixer_file_t *mfile,
 			for (idx = 0; idx < mux1->voices; idx++) {
 				copy_from_user(&eid, &ctrl->data.mux1.poutput[idx], sizeof(eid));
 				kelement = snd_mixer_element_find(mfile->mixer, eid.name, eid.index, eid.type);
-				if (!kelement && !(mux1->attribute & SND_MIXER_MUX1_NONE)) {
+				if (!kelement && !(mux1->attrib & SND_MIXER_MUX1_NONE)) {
 					result = -EINVAL;
 					goto __err;
 				}
@@ -1243,7 +1243,7 @@ static int snd_mixer_lib_mux1_control(snd_kmixer_file_t *mfile,
 		for (idx = 0; idx < mux1->voices; idx++) {
 			memcpy(&eid, (char *)data + sizeof(int) + mux1->voices * sizeof(eid), sizeof(eid));
 			kelement = snd_mixer_element_find(mfile->mixer, eid.name, eid.index, eid.type);
-			if (!kelement && !(mux1->attribute & SND_MIXER_MUX1_NONE)) {
+			if (!kelement && !(mux1->attrib & SND_MIXER_MUX1_NONE)) {
 				result = -EINVAL;
 				goto __err;
 			}
@@ -1266,7 +1266,7 @@ static void snd_mixer_lib_mux1_free(struct snd_stru_mixer_lib_mux1 *mux1)
 snd_kmixer_element_t *snd_mixer_lib_mux1(snd_kmixer_t *mixer,
 					 char *name,
 					 int index,
-					 unsigned int attribute,
+					 unsigned int attrib,
 					 int voices,
 					 snd_mixer_mux1_control_t *control,
 					 void *private_data)
@@ -1279,7 +1279,7 @@ snd_kmixer_element_t *snd_mixer_lib_mux1(snd_kmixer_t *mixer,
 	mux1 = (struct snd_stru_mixer_lib_mux1 *)snd_malloc(sizeof(*mux1));
 	if (!mux1)
 		return NULL;
-	mux1->attribute = attribute;
+	mux1->attrib = attrib;
 	mux1->voices = voices;
 	mux1->control = control;
 	mux1->private_data = private_data;
@@ -1304,7 +1304,7 @@ static int snd_mixer_lib_mux2_info(snd_kmixer_file_t *mfile,
 				   snd_mixer_element_info_t *info,
 				   struct snd_stru_mixer_lib_mux2 *mux2)
 {
-	info->data.mux2.attribute = mux2->attribute;
+	info->data.mux2.attrib = mux2->attrib;
 	return 0;
 }
 
@@ -1340,7 +1340,7 @@ static int snd_mixer_lib_mux2_control(snd_kmixer_file_t *mfile,
 			break;
 		case SND_MIXER_CMD_WRITE:
 			kelement = snd_mixer_element_find(mfile->mixer, ctrl->data.mux2.output.name, ctrl->data.mux2.output.index, ctrl->data.mux2.output.type);
-			if (!kelement && !(mux2->attribute & SND_MIXER_MUX2_NONE))
+			if (!kelement && !(mux2->attrib & SND_MIXER_MUX2_NONE))
 				return -EINVAL;
 			result = mux2->control(1, &kelement, mux2->private_data);
 			break;
@@ -1366,7 +1366,7 @@ static int snd_mixer_lib_mux2_control(snd_kmixer_file_t *mfile,
 			return -EINVAL;
 		memcpy(&eid, data, sizeof(eid));
 		kelement = snd_mixer_element_find(mfile->mixer, eid.name, eid.index, eid.type);
-		if (!kelement && !(mux2->attribute & SND_MIXER_MUX2_NONE))
+		if (!kelement && !(mux2->attrib & SND_MIXER_MUX2_NONE))
 			return -EINVAL;
 		result = mux2->control(1, &kelement, mux2->private_data);
 		if (result >= 0)
@@ -1384,7 +1384,7 @@ static void snd_mixer_lib_mux2_free(struct snd_stru_mixer_lib_mux2 *mux2)
 snd_kmixer_element_t *snd_mixer_lib_mux2(snd_kmixer_t *mixer,
 					 char *name,
 					 int index,
-					 unsigned int attribute,
+					 unsigned int attrib,
 					 snd_mixer_mux2_control_t *control,
 					 void *private_data)
 {
@@ -1396,7 +1396,7 @@ snd_kmixer_element_t *snd_mixer_lib_mux2(snd_kmixer_t *mixer,
 	mux2 = (struct snd_stru_mixer_lib_mux2 *)snd_malloc(sizeof(*mux2));
 	if (!mux2)
 		return NULL;
-	mux2->attribute = attribute;
+	mux2->attrib = attrib;
 	mux2->control = control;
 	mux2->private_data = private_data;
 	memset(&nelement, 0, sizeof(nelement));
