@@ -1834,10 +1834,10 @@ static unsigned int snd_pcm1_poll(struct file *file, poll_table * wait)
 		snd_spin_unlock(record, sleep_lock, &flags);
 	}
 	if (fflags & SND_PCM1_LFLG_PLAY) {
-		snd_spin_lock(record, sleep_lock, &flags);
-		snd_getlock(record, sleep) |= SND_WK_SLEEP;
+		snd_spin_lock(playback, sleep_lock, &flags);
+		snd_getlock(playback, sleep) |= SND_WK_SLEEP;
 		snd_poll_wait(file, playback, sleep, wait);
-		snd_spin_unlock(record, sleep_lock, &flags);
+		snd_spin_unlock(playback, sleep_lock, &flags);
 	}
 	mask = 0;
 	if (fflags & SND_PCM1_LFLG_RECORD) {
